pub enum PublishError {
Query(QueryError),
Concurrency(ConcurrencyError),
UnexpectedResponses,
}Expand description
Errors occurring during publishing a SignedPacket
Variants
Query(QueryError)
Errors that requires either a retry or debugging the network condition.
Concurrency(ConcurrencyError)
A different SignedPacket is being concurrently published for the same PublicKey.
This risks a lost update, you should resolve most recent SignedPacket before publishing again.
UnexpectedResponses
All relays responded with unexpected responses, check debug logs.