pub enum QueryError {
Timeout,
NoClosestNodes,
DhtErrorResponse(i32, String),
BadRequest,
}Expand description
Errors that requires either a retry or debugging the network condition.
Variants
Timeout
Publish query timed out with no responses neither success or errors, from Dht or relays.
NoClosestNodes
Publishing SignedPacket to Mainline failed.
DhtErrorResponse(i32, String)
Publishing SignedPacket to Mainline failed, received an error response.
BadRequest
Most relays responded with bad request