pub enum SignedPacketVerifyError {
SignatureError(SignatureError),
DnsError(SimpleDnsError),
InvalidSignedPacketBytesLength(usize),
PacketTooLarge(usize),
PublicKeyError(PublicKeyError),
}Expand description
Errors trying to parse or create a SignedPacket
Variants
SignatureError(SignatureError)
Errors which may occur while processing signatures and keypairs.
DnsError(SimpleDnsError)
Transparent simple_dns::SimpleDnsError
InvalidSignedPacketBytesLength(usize)
Serialized signed packets are <32 bytes publickey><64 bytes signature><8 bytes timestamp><less than or equal to 1000 bytes encoded dns packet>.
PacketTooLarge(usize)
DNS packet endocded and compressed is larger than 1000 bytes
PublicKeyError(PublicKeyError)
Errors while trying to create a PublicKey