pub struct LmdbCache { /* private fields */ }Expand description
Persistent crate::Cache implementation using LMDB’s bindings heed
Implementations
Sourceimpl LmdbCache
impl LmdbCache
Sourcepub unsafe fn open(env_path: &Path, capacity: usize) -> Result<Self, Error>
pub unsafe fn open(env_path: &Path, capacity: usize) -> Result<Self, Error>
Creates a new LmdbCache at the env_path and set the heed::EnvOpenOptions::map_size
to a multiple of the capacity by SignedPacket::MAX_BYTES, aligned to system’s page size,
a maximum of 10 TB, and a minimum of 10 MB.
Safety
LmdbCache uses LMDB, opening which is marked unsafe, because the possible Undefined Behavior (UB) if the lock file is broken.
Sourcepub fn open_unsafe(env_path: &Path, capacity: usize) -> Result<Self, Error>
pub fn open_unsafe(env_path: &Path, capacity: usize) -> Result<Self, Error>
Convenient wrapper around Self::open.
Make sure to read the safety section in Self::open