pub struct SignedPacketBuilder { /* private fields */ }Expand description
A builder for SignedPacket with many convenient methods, see SignedPacket::builder documentation for examples of how to use this builder.
Implementations
Sourceimpl SignedPacketBuilder
impl SignedPacketBuilder
Sourcepub fn record(self, record: ResourceRecord<'_>) -> Self
pub fn record(self, record: ResourceRecord<'_>) -> Self
Insert a ResourceRecord
Sourcepub fn rdata(self, name: Name<'_>, rdata: RData<'_>, ttl: u32) -> Self
pub fn rdata(self, name: Name<'_>, rdata: RData<'_>, ttl: u32) -> Self
Insert any type of RData
You can set the name to . to point or the Apex
(the public key, of the keypair used in Self::sign)
Sourcepub fn a(self, name: Name<'_>, address: Ipv4Addr, ttl: u32) -> Self
pub fn a(self, name: Name<'_>, address: Ipv4Addr, ttl: u32) -> Self
Insert an A record.
You can set the name to . to point or the Apex
(the public key, of the keypair used in Self::sign)
Sourcepub fn aaaa(self, name: Name<'_>, address: Ipv6Addr, ttl: u32) -> Self
pub fn aaaa(self, name: Name<'_>, address: Ipv6Addr, ttl: u32) -> Self
Insert an AAAA record.
You can set the name to . to point or the Apex
(the public key, of the keypair used in Self::sign)
Sourcepub fn address(self, name: Name<'_>, address: IpAddr, ttl: u32) -> Self
pub fn address(self, name: Name<'_>, address: IpAddr, ttl: u32) -> Self
Insert an A or AAAA record.
You can set the name to . to point or the Apex
(the public key, of the keypair used in Self::sign)
Sourcepub fn cname(self, name: Name<'_>, cname: Name<'_>, ttl: u32) -> Self
pub fn cname(self, name: Name<'_>, cname: Name<'_>, ttl: u32) -> Self
Insert a CNAME record.
You can set the name to . to point or the Apex
(the public key, of the keypair used in Self::sign)
Sourcepub fn txt(self, name: Name<'_>, text: TXT<'_>, ttl: u32) -> Self
pub fn txt(self, name: Name<'_>, text: TXT<'_>, ttl: u32) -> Self
Insert a TXT record.
You can set the name to . to point or the Apex
(the public key, of the keypair used in Self::sign)
Sourcepub fn https(self, name: Name<'_>, svcb: SVCB<'_>, ttl: u32) -> Self
pub fn https(self, name: Name<'_>, svcb: SVCB<'_>, ttl: u32) -> Self
Insert an HTTPS record
You can set the name to . to point or the Apex
(the public key, of the keypair used in Self::sign)
Sourcepub fn svcb(self, name: Name<'_>, svcb: SVCB<'_>, ttl: u32) -> Self
pub fn svcb(self, name: Name<'_>, svcb: SVCB<'_>, ttl: u32) -> Self
Insert an `SVCB record
You can set the name to . to point or the Apex
(the public key, of the keypair used in Self::sign)
Sourcepub fn build(
self,
keypair: &Keypair,
) -> Result<SignedPacket, SignedPacketBuildError>
pub fn build( self, keypair: &Keypair, ) -> Result<SignedPacket, SignedPacketBuildError>
Alias to Self::sign
Sourcepub fn sign(
self,
keypair: &Keypair,
) -> Result<SignedPacket, SignedPacketBuildError>
pub fn sign( self, keypair: &Keypair, ) -> Result<SignedPacket, SignedPacketBuildError>
Create a Packet from the ResourceRecords inserted so far and sign it with the given Keypair.
Read more about how names will be normalized in SignedPacket::new.