pub enum ConcurrencyError {
ConflictRisk,
NotMostRecent,
CasFailed,
}Expand description
Errors that requires resolving most recent SignedPacket before publishing.
Variants
ConflictRisk
A different SignedPacket is being concurrently published for the same PublicKey.
This risks a lost update, you should resolve most recent SignedPacket before publishing again.
NotMostRecent
Found a more recent SignedPacket in the client’s cache
This risks a lost update, you should resolve most recent SignedPacket before publishing again.
CasFailed
Compare and swap failed; there is a more recent SignedPacket than the one seen before publishing
This risks a lost update, you should resolve most recent SignedPacket before publishing again.